(ns wanijo.visualisation.domain
  (:require [wanijo.framework.neo4j :as neo4j]
            [wanijo.instance.domain :as domain-instance]))

(neo4j/defquery all-instance-connections
  "MATCH
     (source:instance)-[:of]->(schema:schema)
   OPTIONAL MATCH
     (source)<-[:link_from]-(link:link)-[:link_to]->(target:instance),
     (target)-[:of]->(target_schema:schema)
   RETURN source, schema, link, target, target_schema")
(defn all-instance-connections! []
  (neo4j/exec-query! all-instance-connections {}))

(neo4j/defquery search
  "MATCH (i:instance)
   WHERE i.name =~ {term}
   RETURN i
   LIMIT 10")
(defn enrich-links [instance]
  (update instance
          :links-out
          (fn [links-in]
            (map #(assoc
                    (domain-instance/full-instance-by-uuid!
                      (-> % :target :uuid))
                    :link-name
                    (-> % :label :name))
                 links-in))))
(defn search! [term]
  (->> (neo4j/exec-query! search {:term (str ".*" term ".*")})
       (map #(domain-instance/full-instance-by-uuid! (-> % :i :uuid)))
       (map enrich-links)))

(defn instance! [uuid]
  (enrich-links (domain-instance/full-instance-by-uuid! uuid)))
